@@ -20,6 +20,7 @@ import (
 	"net/url"
 	"os"
 	"runtime"
+	"strconv"
 	"strings"
 	"time"
 
@@ -30,7 +31,7 @@ import (
 )
 
 const (
-	version             = "0.5.6"
+	version             = "0.6.0"
 	nsBOSH              = "urn:xmpp:alt-connections:xbosh"
 	nsC2SdTLS           = "urn:xmpp:alt-connections:tls"
 	nsC2SQuic           = "urn:xmpp:alt-connections:quic"
@@ -90,7 +91,7 @@ func main() {
 	flagTLSVersion := getopt.IntLong("tls-version", 0, 12,
 		"Minimal TLS version. 10 (TSLv1.0), 11 (TLSv1.1), 12 (TLSv1.2) or 13 (TLSv1.3).")
 	flagVersion := getopt.BoolLong("version", 0, "Show version information.")
-	flagFallback := getopt.BoolLong("fallback", 'f', "Check fallback (Standard ports on A/AAAA records)"+
+	flagFallback := getopt.BoolLong("fallback", 'f', "Additionally check fallback (Standard ports on A/AAAA records)"+
 		" if no SRV records are provided.")
 	flagForceFallback := getopt.BoolLong("force-fallback", 0, "Check fallback (Standard ports on A/AAAA records)"+
 		" even if SRV records are provided.")
@@ -98,6 +99,10 @@ func main() {
 	flagResolver := getopt.StringLong("resolver", 0, "", "Custom resolver e.g. \"1.1.1.1\" for common DNS"+
 		" or \"5.1.66.255#dot.ffmuc.net\" for usage with \"--dot\".")
 	flagDoT := getopt.BoolLong("dot", 0, "Use DNSoverTLS (DoT), see also \"--resolver\".")
+	flagClientDTLS := getopt.ListLong("client-dtls", 0, "Add an arbitrary target for C2S with direct TLS in the form domain:port. Can be invoked several times.")
+	flagClientSTLS := getopt.ListLong("client-stls", 0, "Add an arbitrary target for C2S with StartTLS in the form domain:port. Can be invoked several times.")
+	flagServerDTLS := getopt.ListLong("server-dtls", 0, "Add an arbitrary target for S2S with direct TLS in the form domain:port. Can be invoked several times.")
+	flagServerSTLS := getopt.ListLong("server-stls", 0, "Add an arbitrary target for S2S with StartTLS in the form domain:port. Can be invoked several times.")
 
 	// Parse command line flags.
 	getopt.Parse()
@@ -151,6 +156,7 @@ func main() {
 
 	// Read server from command line.
 	server := getopt.Args()
+	fmt.Println("args:", server)
 	switch count := len(server); {
 	case count == 0:
 		log.Fatal("Please specify a server.")
@@ -207,6 +213,38 @@ func main() {
 				fmt.Println()
 			}
 		}
+		if len(*flagClientDTLS) > 0 {
+			for _, cdtls := range *flagClientDTLS {
+				target := strings.SplitN(cdtls, ":", 2)
+				port, err := strconv.ParseUint(target[1], 10, 16)
+				if err != nil {
+					fmt.Println(err)
+					continue
+				}
+				cr := xmppsrv.SRV{
+					Type:   "xmpps-client",
+					Target: target[0],
+					Port:   uint16(port),
+				}
+				clientRecords = append(clientRecords, cr)
+			}
+		}
+		if len(*flagClientSTLS) > 0 {
+			for _, cstls := range *flagClientSTLS {
+				target := strings.SplitN(cstls, ":", 2)
+				port, err := strconv.ParseUint(target[1], 10, 16)
+				if err != nil {
+					fmt.Println(err)
+					continue
+				}
+				cr := xmppsrv.SRV{
+					Type:   "xmpp-client",
+					Target: target[0],
+					Port:   uint16(port),
+				}
+				clientRecords = append(clientRecords, cr)
+			}
+		}
 		if *flagForceFallback && !fallback && *flagTest {
 			if len(clientRecords) > 0 {
 				var standardPort bool
@@ -249,6 +287,38 @@ func main() {
 				fmt.Println()
 			}
 		}
+		if len(*flagServerDTLS) > 0 {
+			for _, sdtls := range *flagServerDTLS {
+				target := strings.SplitN(sdtls, ":", 2)
+				port, err := strconv.ParseUint(target[1], 10, 16)
+				if err != nil {
+					fmt.Println(err)
+					continue
+				}
+				sr := xmppsrv.SRV{
+					Type:   "xmpps-server",
+					Target: target[0],
+					Port:   uint16(port),
+				}
+				serverRecords = append(serverRecords, sr)
+			}
+		}
+		if len(*flagServerSTLS) > 0 {
+			for _, sstls := range *flagServerSTLS {
+				target := strings.SplitN(sstls, ":", 2)
+				port, err := strconv.ParseUint(target[1], 10, 16)
+				if err != nil {
+					fmt.Println(err)
+					continue
+				}
+				sr := xmppsrv.SRV{
+					Type:   "xmpp-server",
+					Target: target[0],
+					Port:   uint16(port),
+				}
+				serverRecords = append(serverRecords, sr)
+			}
+		}
 		if *flagForceFallback && !fallback && *flagTest {
 			if len(serverRecords) > 0 {
 				var standardPort bool
